==> eam-wshub-proxyclient-11.6-1-sources.jar: org/openapplications/oagis_segments/QUANTITY.java <==

package org.openapplications.oagis_segments;

import java.math.BigDecimal;
import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Classe Java pour QUANTITY complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="QUANTITY">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}VALUE"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}NUMOFDEC"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SIGN"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}UOM"/>
 *       &lt;/sequence>
 *       &lt;attribute name="qualifier" use="required">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}NMTOKEN">
 *             &lt;enumeration value="ACCEPTED"/>
 *             &lt;enumeration value="ACTDUR"/>
 *             &lt;enumeration value="ACTHRS"/>
 *             &lt;enumeration value="ALLOCATED"/>
 *             &lt;enumeration value="ALLOWEDWT"/>
 *             &lt;enumeration value="AVAILABLE"/>
 *             &lt;enumeration value="AVGRUNSIZE"/>
 *             &lt;enumeration value="BACKORDERD"/>
 *             &lt;enumeration value="BATCHSIZE"/>
 *             &lt;enumeration value="BATCHTIME"/>
 *             &lt;enumeration value="BLOCKED"/>
 *             &lt;enumeration value="BREAKTIME"/>
 *             &lt;enumeration value="CAPPERCENT"/>
 *             &lt;enumeration value="CATCHWEGHT"/>
 *             &lt;enumeration value="COMMISSION"/>
 *             &lt;enumeration value="COMPLETED"/>
 *             &lt;enumeration value="CUMULATIVE"/>
 *             &lt;enumeration value="DELIVERED"/>
 *             &lt;enumeration value="DURATION"/>
 *             &lt;enumeration value="DUROVER"/>
 *             &lt;enumeration value="DURUNDER"/>
 *             &lt;enumeration value="EMPLOYEES"/>
 *             &lt;enumeration value="EMPREQD"/>
 *             &lt;enumeration value="ESTDUR"/>
 *             &lt;enumeration value="ESTHRS"/>
 *             &lt;enumeration value="ESTWEIGHT"/>
 *             &lt;enumeration value="FILENAME"/>
 *             &lt;enumeration value="FILESIZE"/>
 *             &lt;enumeration value="FIXEDTIME"/>
 *             &lt;enumeration value="HEIGHT"/>
 *             &lt;enumeration value="INSPECTED"/>
 *             &lt;enumeration value="INSPECTION"/>
 *             &lt;enumeration value="ITEM"/>
 *             &lt;enumeration value="LDTMOFFSET"/>
 *             &lt;enumeration value="LENGTH"/>
 *             &lt;enumeration value="LABOR"/>
 *             &lt;enumeration value="LOADINGWT"/>
 *             &lt;enumeration value="LOTSIZEMAX"/>
 *             &lt;enumeration value="LOTSIZEMIN"/>
 *             &lt;enumeration value="LOTSIZEMLT"/>
 *             &lt;enumeration value="LOWERLIMIT"/>
 *             &lt;enumeration value="MACHINEHRS"/>
 *             &lt;enumeration value="MAXIMUM"/>
 *             &lt;enumeration value="MAXPARLTM"/>
 *             &lt;enumeration value="MINIMUM"/>
 *             &lt;enumeration value="MOVETIME"/>
 *             &lt;enumeration value="MSMENT"/>
 *             &lt;enumeration value="MULTIPLIER"/>
 *             &lt;enumeration value="NETWEIGHT"/>
 *             &lt;enumeration value="OPEN"/>
 *             &lt;enumeration value="ORDERED"/>
 *             &lt;enumeration value="OTHERREJ"/>
 *             &lt;enumeration value="OVERSHIP"/>
 *             &lt;enumeration value="PACKING"/>
 *             &lt;enumeration value="PERCENT"/>
 *             &lt;enumeration value="PERCENTREQ"/>
 *             &lt;enumeration value="PERSHBNOPR"/>
 *             &lt;enumeration value="PERSHWIOPR"/>
 *             &lt;enumeration value="PLNDPRCT"/>
 *             &lt;enumeration value="PRCBRK"/>
 *             &lt;enumeration value="PRIOR"/>
 *             &lt;enumeration value="QUEUETIME"/>
 *             &lt;enumeration value="RATE"/>
 *             &lt;enumeration value="RECEIVED"/>
 *             &lt;enumeration value="REJECTED"/>
 *             &lt;enumeration value="REJFIXED"/>
 *             &lt;enumeration value="REJPERCENT"/>
 *             &lt;enumeration value="REMDUR"/>
 *             &lt;enumeration value="REMHRS"/>
 *             &lt;enumeration value="REQUIRED"/>
 *             &lt;enumeration value="RETURNED"/>
 *             &lt;enumeration value="REWORK"/>
 *             &lt;enumeration value="RUNTIME"/>
 *             &lt;enumeration value="SCRAP"/>
 *             &lt;enumeration value="SETUPTIME"/>
 *             &lt;enumeration value="SHELFLIFE"/>
 *             &lt;enumeration value="SHIPPED"/>
 *             &lt;enumeration value="SHIPUNIT"/>
 *             &lt;enumeration value="START"/>
 *             &lt;enumeration value="TEARDOWN"/>
 *             &lt;enumeration value="TOOLREQD"/>
 *             &lt;enumeration value="TOTWEIGHT"/>
 *             &lt;enumeration value="TRANSFRLOT"/>
 *             &lt;enumeration value="UNDERSHIP"/>
 *             &lt;enumeration value="UNIT"/>
 *             &lt;enumeration value="UPPERLIMIT"/>
 *             &lt;enumeration value="VOLUME"/>
 *             &lt;enumeration value="WAITTIME"/>
 *             &lt;enumeration value="WEIGHT"/>
 *             &lt;enumeration value="WIDTH"/>
 *             &lt;enumeration value="OTHER"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUANTITY", propOrder = {
    "value",
    "numofdec",
    "sign",
    "uom"
})
public class QUANTITY {

    @XmlElement(name = "VALUE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigDecimal value;
    @XmlElement(name = "NUMOFDEC", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger numofdec;
    @XmlElement(name = "SIGN", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected String sign;
    @XmlElement(name = "UOM", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected String uom;
    @XmlAttribute(name = "qualifier", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String qualifier;

    /**
     * Obtient la valeur de la propriété value.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getVALUE() {
        return value;
    }

    /**
     * Définit la valeur de la propriété value.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setVALUE(BigDecimal value) {
        this.value = value;
    }

    /**
     * Obtient la valeur de la propriété numofdec.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNUMOFDEC() {
        return numofdec;
    }

    /**
     * Définit la valeur de la propriété numofdec.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNUMOFDEC(BigInteger value) {
        this.numofdec = value;
    }

    /**
     * Obtient la valeur de la propriété sign.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSIGN() {
        return sign;
    }

    /**
     * Définit la valeur de la propriété sign.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSIGN(String value) {
        this.sign = value;
    }

    /**
     * Obtient la valeur de la propriété uom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOM() {
        return uom;
    }

    /**
     * Définit la valeur de la propriété uom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOM(String value) {
        this.uom = value;
    }

    /**
     * Obtient la valeur de la propriété qualifier.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQualifier() {
        return qualifier;
    }

    /**
     * Définit la valeur de la propriété qualifier.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQualifier(String value) {
        this.qualifier = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: org/openapplications/oagis_segments/QUANTITY.java <==

package org.openapplications.oagis_segments;

import java.math.BigDecimal;
import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;


/**
 * <p>Java class for QUANTITY complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="QUANTITY">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}VALUE"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}NUMOFDEC"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SIGN"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}UOM"/>
 *       &lt;/sequence>
 *       &lt;attribute name="qualifier" use="required">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}NMTOKEN">
 *             &lt;enumeration value="ACCEPTED"/>
 *             &lt;enumeration value="ACTDUR"/>
 *             &lt;enumeration value="ACTHRS"/>
 *             &lt;enumeration value="ALLOCATED"/>
 *             &lt;enumeration value="ALLOWEDWT"/>
 *             &lt;enumeration value="AVAILABLE"/>
 *             &lt;enumeration value="AVGRUNSIZE"/>
 *             &lt;enumeration value="BACKORDERD"/>
 *             &lt;enumeration value="BATCHSIZE"/>
 *             &lt;enumeration value="BATCHTIME"/>
 *             &lt;enumeration value="BLOCKED"/>
 *             &lt;enumeration value="BREAKTIME"/>
 *             &lt;enumeration value="CAPPERCENT"/>
 *             &lt;enumeration value="CATCHWEGHT"/>
 *             &lt;enumeration value="COMMISSION"/>
 *             &lt;enumeration value="COMPLETED"/>
 *             &lt;enumeration value="CUMULATIVE"/>
 *             &lt;enumeration value="DELIVERED"/>
 *             &lt;enumeration value="DURATION"/>
 *             &lt;enumeration value="DUROVER"/>
 *             &lt;enumeration value="DURUNDER"/>
 *             &lt;enumeration value="EMPLOYEES"/>
 *             &lt;enumeration value="EMPREQD"/>
 *             &lt;enumeration value="ESTDUR"/>
 *             &lt;enumeration value="ESTHRS"/>
 *             &lt;enumeration value="ESTWEIGHT"/>
 *             &lt;enumeration value="FILENAME"/>
 *             &lt;enumeration value="FILESIZE"/>
 *             &lt;enumeration value="FIXEDTIME"/>
 *             &lt;enumeration value="HEIGHT"/>
 *             &lt;enumeration value="INSPECTED"/>
 *             &lt;enumeration value="INSPECTION"/>
 *             &lt;enumeration value="ITEM"/>
 *             &lt;enumeration value="LDTMOFFSET"/>
 *             &lt;enumeration value="LENGTH"/>
 *             &lt;enumeration value="LABOR"/>
 *             &lt;enumeration value="LOADINGWT"/>
 *             &lt;enumeration value="LOTSIZEMAX"/>
 *             &lt;enumeration value="LOTSIZEMIN"/>
 *             &lt;enumeration value="LOTSIZEMLT"/>
 *             &lt;enumeration value="LOWERLIMIT"/>
 *             &lt;enumeration value="MACHINEHRS"/>
 *             &lt;enumeration value="MAXIMUM"/>
 *             &lt;enumeration value="MAXPARLTM"/>
 *             &lt;enumeration value="MINIMUM"/>
 *             &lt;enumeration value="MOVETIME"/>
 *             &lt;enumeration value="MSMENT"/>
 *             &lt;enumeration value="MULTIPLIER"/>
 *             &lt;enumeration value="NETWEIGHT"/>
 *             &lt;enumeration value="OPEN"/>
 *             &lt;enumeration value="ORDERED"/>
 *             &lt;enumeration value="OTHERREJ"/>
 *             &lt;enumeration value="OVERSHIP"/>
 *             &lt;enumeration value="PACKING"/>
 *             &lt;enumeration value="PERCENT"/>
 *             &lt;enumeration value="PERCENTREQ"/>
 *             &lt;enumeration value="PERSHBNOPR"/>
 *             &lt;enumeration value="PERSHWIOPR"/>
 *             &lt;enumeration value="PLNDPRCT"/>
 *             &lt;enumeration value="PRCBRK"/>
 *             &lt;enumeration value="PRIOR"/>
 *             &lt;enumeration value="QUEUETIME"/>
 *             &lt;enumeration value="RATE"/>
 *             &lt;enumeration value="RECEIVED"/>
 *             &lt;enumeration value="REJECTED"/>
 *             &lt;enumeration value="REJFIXED"/>
 *             &lt;enumeration value="REJPERCENT"/>
 *             &lt;enumeration value="REMDUR"/>
 *             &lt;enumeration value="REMHRS"/>
 *             &lt;enumeration value="REQUIRED"/>
 *             &lt;enumeration value="RETURNED"/>
 *             &lt;enumeration value="REWORK"/>
 *             &lt;enumeration value="RUNTIME"/>
 *             &lt;enumeration value="SCRAP"/>
 *             &lt;enumeration value="SETUPTIME"/>
 *             &lt;enumeration value="SHELFLIFE"/>
 *             &lt;enumeration value="SHIPPED"/>
 *             &lt;enumeration value="SHIPUNIT"/>
 *             &lt;enumeration value="START"/>
 *             &lt;enumeration value="TEARDOWN"/>
 *             &lt;enumeration value="TOOLREQD"/>
 *             &lt;enumeration value="TOTWEIGHT"/>
 *             &lt;enumeration value="TRANSFRLOT"/>
 *             &lt;enumeration value="UNDERSHIP"/>
 *             &lt;enumeration value="UNIT"/>
 *             &lt;enumeration value="UPPERLIMIT"/>
 *             &lt;enumeration value="VOLUME"/>
 *             &lt;enumeration value="WAITTIME"/>
 *             &lt;enumeration value="WEIGHT"/>
 *             &lt;enumeration value="WIDTH"/>
 *             &lt;enumeration value="OTHER"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUANTITY", propOrder = {
    "value",
    "numofdec",
    "sign",
    "uom"
})
public class QUANTITY {

    @XmlElement(name = "VALUE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigDecimal value;
    @XmlElement(name = "NUMOFDEC", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger numofdec;
    @XmlElement(name = "SIGN", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected String sign;
    @XmlElement(name = "UOM", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected String uom;
    @XmlAttribute(name = "qualifier", required = true)
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String qualifier;

    /**
     * Gets the value of the value property.
     * 
     * @return
     *     possible object is
     *     {@link BigDecimal }
     *     
     */
    public BigDecimal getVALUE() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigDecimal }
     *     
     */
    public void setVALUE(BigDecimal value) {
        this.value = value;
    }

    /**
     * Gets the value of the numofdec property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getNUMOFDEC() {
        return numofdec;
    }

    /**
     * Sets the value of the numofdec property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setNUMOFDEC(BigInteger value) {
        this.numofdec = value;
    }

    /**
     * Gets the value of the sign property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSIGN() {
        return sign;
    }

    /**
     * Sets the value of the sign property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSIGN(String value) {
        this.sign = value;
    }

    /**
     * Gets the value of the uom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOM() {
        return uom;
    }

    /**
     * Sets the value of the uom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOM(String value) {
        this.uom = value;
    }

    /**
     * Gets the value of the qualifier property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getQualifier() {
        return qualifier;
    }

    /**
     * Sets the value of the qualifier property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setQualifier(String value) {
        this.qualifier = value;
    }

}
